import { KernelMessage } from '@jupyterlab/services';
import { BaseKernel, IKernel } from '@jupyterlite/kernel';
/**
 * A kernel that executes code in an IFrame.
 */
export declare class JavaScriptKernel extends BaseKernel implements IKernel {
    /**
     * Instantiate a new JavaScriptKernel
     *
     * @param options The instantiation options for a new JavaScriptKernel
     */
    constructor(options: IKernel.IOptions);
    /**
     * Dispose the kernel.
     */
    dispose(): void;
    /**
     * A promise that is fulfilled when the kernel is ready.
     */
    get ready(): Promise<void>;
    /**
     * Handle a kernel_info_request message
     */
    kernelInfoRequest(): Promise<KernelMessage.IInfoReplyMsg['content']>;
    /**
     * Handle an `execute_request` message
     *
     * @param msg The parent message.
     */
    executeRequest(content: KernelMessage.IExecuteRequestMsg['content']): Promise<KernelMessage.IExecuteReplyMsg['content']>;
    /**
     * Handle an complete_request message
     *
     * @param msg The parent message.
     */
    completeRequest(content: KernelMessage.ICompleteRequestMsg['content']): Promise<KernelMessage.ICompleteReplyMsg['content']>;
    /**
     * Handle an `inspect_request` message.
     *
     * @param content - The content of the request.
     *
     * @returns A promise that resolves with the response message.
     */
    inspectRequest(content: KernelMessage.IInspectRequestMsg['content']): Promise<KernelMessage.IInspectReplyMsg['content']>;
    /**
     * Handle an `is_complete_request` message.
     *
     * @param content - The content of the request.
     *
     * @returns A promise that resolves with the response message.
     */
    isCompleteRequest(content: KernelMessage.IIsCompleteRequestMsg['content']): Promise<KernelMessage.IIsCompleteReplyMsg['content']>;
    /**
     * Handle a `comm_info_request` message.
     *
     * @param content - The content of the request.
     *
     * @returns A promise that resolves with the response message.
     */
    commInfoRequest(content: KernelMessage.ICommInfoRequestMsg['content']): Promise<KernelMessage.ICommInfoReplyMsg['content']>;
    /**
     * Send an `input_reply` message.
     *
     * @param content - The content of the reply.
     */
    inputReply(content: KernelMessage.IInputReplyMsg['content']): void;
    /**
     * Send an `comm_open` message.
     *
     * @param msg - The comm_open message.
     */
    commOpen(msg: KernelMessage.ICommOpenMsg): Promise<void>;
    /**
     * Send an `comm_msg` message.
     *
     * @param msg - The comm_msg message.
     */
    commMsg(msg: KernelMessage.ICommMsgMsg): Promise<void>;
    /**
     * Send an `comm_close` message.
     *
     * @param close - The comm_close message.
     */
    commClose(msg: KernelMessage.ICommCloseMsg): Promise<void>;
    /**
     * Execute code in the kernel IFrame.
     *
     * @param code The code to execute.
     */
    protected _eval(code: string): string;
    /**
     * Create a new IFrame
     *
     * @param iframe The IFrame to initialize.
     */
    protected _initIFrame(): Promise<void>;
    private _iframe;
    private _evalFunc;
    private _ready;
}
